# PoPEx Python3 Package

This python3 package is an implementation of the parallelized adaptive importance sampler. PoPEx is a robust method to solve the inverse problem when the parameters are categorical (such as rock types) and when a prior geostatistical model is defined.

The method is described in detail in the following references:
- Jäggli C, Straubhaar J and Renard P (2018) Parallelized Adaptive Importance Sampling for Solving Inverse Problems. Front. Earth Sci. 6:203. doi: [10.3389/feart.2018.00203](https://www.frontiersin.org/articles/10.3389/feart.2018.00203/full)  
- Jäggli, C., Straubhaar, J., and Renard, P. (2017). Posterior population expansion for solving inverse problems. Water Resour. Res. 53, 2902–2916. doi: [10.1002/2016WR019550](http://dx.doi.org/10.1002/2016WR019550)


## Documentation

Find the documentation of the package under

[![Documentation Status](https://readthedocs.org/projects/popex/badge/?version=latest)](https://popex.readthedocs.io/en/latest/?badge=latest)
